@@ -1,30 +1,35 @@
 import socket
+import struct
 from collections import defaultdict, deque
-from datetime import datetime as Datetime
-from decimal import Decimal
 from distutils.version import LooseVersion
 from hashlib import md5
 from itertools import count
 from struct import Struct
 
-from pg8000 import converters
-from pg8000.exceptions import DatabaseError, InterfaceError
+import scramp
 
-from scramp import ScramClient
+from pg8000.converters import (
+    PG_PY_ENCODINGS,
+    PG_TYPES,
+    PY_TYPES,
+    make_params,
+    string_in,
+)
+from pg8000.exceptions import DatabaseError, InterfaceError
 
 
 def pack_funcs(fmt):
-    struc = Struct('!' + fmt)
+    struc = Struct(f"!{fmt}")
     return struc.pack, struc.unpack_from
 
 
-i_pack, i_unpack = pack_funcs('i')
-h_pack, h_unpack = pack_funcs('h')
-ii_pack, ii_unpack = pack_funcs('ii')
-ihihih_pack, ihihih_unpack = pack_funcs('ihihih')
-ci_pack, ci_unpack = pack_funcs('ci')
-bh_pack, bh_unpack = pack_funcs('bh')
-cccc_pack, cccc_unpack = pack_funcs('cccc')
+i_pack, i_unpack = pack_funcs("i")
+h_pack, h_unpack = pack_funcs("h")
+ii_pack, ii_unpack = pack_funcs("ii")
+ihihih_pack, ihihih_unpack = pack_funcs("ihihih")
+ci_pack, ci_unpack = pack_funcs("ci")
+bh_pack, bh_unpack = pack_funcs("bh")
+cccc_pack, cccc_unpack = pack_funcs("cccc")
 
 
 # Copyright (c) 2007-2009, Mathieu Fenniak
@@ -58,12 +63,7 @@ cccc_pack, cccc_unpack = pack_funcs('cccc')
 __author__ = "Mathieu Fenniak"
 
 
-min_int2, max_int2 = -2 ** 15, 2 ** 15
-min_int4, max_int4 = -2 ** 31, 2 ** 31
-min_int8, max_int8 = -2 ** 63, 2 ** 63
-
-
-NULL_BYTE = b'\x00'
+NULL_BYTE = b"\x00"
 
 
 # Message codes
@@ -93,15 +93,15 @@ BIND = b"B"
 PARSE = b"P"
 QUERY = b"Q"
 EXECUTE = b"E"
-FLUSH = b'H'
-SYNC = b'S'
-PASSWORD = b'p'
-DESCRIBE = b'D'
-TERMINATE = b'X'
-CLOSE = b'C'
+FLUSH = b"H"
+SYNC = b"S"
+PASSWORD = b"p"
+DESCRIBE = b"D"
+TERMINATE = b"X"
+CLOSE = b"C"
 
 
-def create_message(code, data=b''):
+def create_message(code, data=b""):
     return code + i_pack(len(data) + 4) + data
 
 
@@ -112,8 +112,8 @@ COPY_DONE_MSG = create_message(COPY_DONE)
 EXECUTE_MSG = create_message(EXECUTE, NULL_BYTE + i_pack(0))
 
 # DESCRIBE constants
-STATEMENT = b'S'
-PORTAL = b'P'
+STATEMENT = b"S"
+PORTAL = b"P"
 
 # ErrorResponse codes
 RESPONSE_SEVERITY = "S"  # always present
@@ -135,7 +135,7 @@ IDLE_IN_TRANSACTION = b"T"
 IDLE_IN_FAILED_TRANSACTION = b"E"
 
 
-class CoreConnection():
+class CoreConnection:
     def __enter__(self):
         return self
 
@@ -143,43 +143,56 @@ class CoreConnection():
         self.close()
 
     def __init__(
-            self, user, host='localhost', database=None, port=5432,
-            password=None, source_address=None, unix_sock=None,
-            ssl_context=None, timeout=None, tcp_keepalive=True,
-            application_name=None, replication=None):
+        self,
+        user,
+        host="localhost",
+        database=None,
+        port=5432,
+        password=None,
+        source_address=None,
+        unix_sock=None,
+        ssl_context=None,
+        timeout=None,
+        tcp_keepalive=True,
+        application_name=None,
+        replication=None,
+    ):
         self._client_encoding = "utf8"
         self._commands_with_count = (
-            b"INSERT", b"DELETE", b"UPDATE", b"MOVE", b"FETCH", b"COPY",
-            b"SELECT")
+            b"INSERT",
+            b"DELETE",
+            b"UPDATE",
+            b"MOVE",
+            b"FETCH",
+            b"COPY",
+            b"SELECT",
+        )
         self.notifications = deque(maxlen=100)
         self.notices = deque(maxlen=100)
         self.parameter_statuses = deque(maxlen=100)
 
         if user is None:
-            raise InterfaceError(
-                "The 'user' connection parameter cannot be None")
+            raise InterfaceError("The 'user' connection parameter cannot be None")
 
         init_params = {
-            'user': user,
-            'database': database,
-            'application_name': application_name,
-            'replication': replication
+            "user": user,
+            "database": database,
+            "application_name": application_name,
+            "replication": replication,
         }
 
         for k, v in tuple(init_params.items()):
             if isinstance(v, str):
-                init_params[k] = v.encode('utf8')
+                init_params[k] = v.encode("utf8")
             elif v is None:
                 del init_params[k]
             elif not isinstance(v, (bytes, bytearray)):
-                raise InterfaceError(
-                    "The parameter " + k + " can't be of type " +
-                    str(type(v)) + ".")
+                raise InterfaceError(f"The parameter {k} can't be of type {type(v)}.")
 
-        self.user = init_params['user']
+        self.user = init_params["user"]
 
         if isinstance(password, str):
-            self.password = password.encode('utf8')
+            self.password = password.encode("utf8")
         else:
             self.password = password
 
@@ -192,20 +205,20 @@ class CoreConnection():
         if unix_sock is None and host is not None:
             try:
                 self._usock = socket.create_connection(
-                    (host, port), timeout, source_address)
+                    (host, port), timeout, source_address
+                )
             except socket.error as e:
                 raise InterfaceError(
-                    "Can't create a connection to host " + str(host) +
-                    " and port " + str(port) + " (timeout is " + str(timeout) +
-                    " and source_address is " +
-                    str(source_address) + ").") from e
+                    f"Can't create a connection to host {host} and port {port} "
+                    f"(timeout is {timeout} and source_address is {source_address})."
+                ) from e
 
         elif unix_sock is not None:
             try:
                 if not hasattr(socket, "AF_UNIX"):
                     raise InterfaceError(
-                        "attempt to connect to unix socket on unsupported "
-                        "platform")
+                        "attempt to connect to unix socket on unsupported platform"
+                    )
                 self._usock = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
                 self._usock.settimeout(timeout)
                 self._usock.connect(unix_sock)
@@ -220,6 +233,7 @@ class CoreConnection():
         if tcp_keepalive:
             self._usock.setsockopt(socket.SOL_SOCKET, socket.SO_KEEPALIVE, 1)
 
+        self.channel_binding = None
         if ssl_context is not None:
             try:
                 import ssl
@@ -227,37 +241,58 @@ class CoreConnection():
                 if ssl_context is True:
                     ssl_context = ssl.create_default_context()
 
-                # Int32(8) - Message length, including self.
-                # Int32(80877103) - The SSL request code.
-                self._usock.sendall(ii_pack(8, 80877103))
-                resp = self._usock.recv(1)
-                if resp != b'S':
-                    raise InterfaceError("Server refuses SSL")
+                request_ssl = getattr(ssl_context, "request_ssl", True)
+
+                if request_ssl:
+                    # Int32(8) - Message length, including self.
+                    # Int32(80877103) - The SSL request code.
+                    self._usock.sendall(ii_pack(8, 80877103))
+                    resp = self._usock.recv(1)
+                    if resp != b"S":
+                        raise InterfaceError("Server refuses SSL")
+
+                self._usock = ssl_context.wrap_socket(self._usock, server_hostname=host)
+
+                if request_ssl:
+                    self.channel_binding = scramp.make_channel_binding(
+                        "tls-server-end-point", self._usock
+                    )
 
-                self._usock = ssl_context.wrap_socket(
-                    self._usock, server_hostname=host)
             except ImportError:
                 raise InterfaceError(
-                    "SSL required but ssl module not available in "
-                    "this python installation")
+                    "SSL required but ssl module not available in this python "
+                    "installation."
+                )
 
         self._sock = self._usock.makefile(mode="rwb")
 
-        self._flush = self._sock.flush
-        self._read = self._sock.read
-        self._write = self._sock.write
+        def sock_flush():
+            try:
+                self._sock.flush()
+            except OSError as e:
+                raise InterfaceError("network error on flush") from e
+
+        self._flush = sock_flush
+
+        def sock_read(b):
+            try:
+                return self._sock.read(b)
+            except OSError as e:
+                raise InterfaceError("network error on read") from e
+
+        self._read = sock_read
+
+        def sock_write(d):
+            try:
+                self._sock.write(d)
+            except OSError as e:
+                raise InterfaceError("network error on write") from e
+
+        self._write = sock_write
         self._backend_key_data = None
 
-        self.pg_types = defaultdict(
-            lambda: converters.text_in, converters.PG_TYPES)
-        self.py_types = dict(converters.PY_TYPES)
-
-        self.inspect_funcs = {
-            Datetime: self.inspect_datetime,
-            list: self.array_inspect,
-            tuple: self.array_inspect,
-            int: self.inspect_int
-        }
+        self.pg_types = defaultdict(lambda: string_in, PG_TYPES)
+        self.py_types = dict(PY_TYPES)
 
         self.message_types = {
             NOTICE_RESPONSE: self.handle_NOTICE_RESPONSE,
@@ -280,7 +315,8 @@ class CoreConnection():
             COPY_DONE: self.handle_COPY_DONE,
             COPY_DATA: self.handle_COPY_DATA,
             COPY_IN_RESPONSE: self.handle_COPY_IN_RESPONSE,
-            COPY_OUT_RESPONSE: self.handle_COPY_OUT_RESPONSE}
+            COPY_OUT_RESPONSE: self.handle_COPY_OUT_RESPONSE,
+        }
 
         # Int32 - Message length, including self.
         # Int32(196608) - Protocol version number.  Version 3.0.
@@ -291,7 +327,7 @@ class CoreConnection():
         val = bytearray(i_pack(protocol))
 
         for k, v in init_params.items():
-            val.extend(k.encode('ascii') + NULL_BYTE + v + NULL_BYTE)
+            val.extend(k.encode("ascii") + NULL_BYTE + v + NULL_BYTE)
         val.append(0)
         self._write(i_pack(len(val) + 4))
         self._write(val)
@@ -314,10 +350,10 @@ class CoreConnection():
 
     def handle_ERROR_RESPONSE(self, data, ps):
         msg = dict(
-            (
-                s[:1].decode(self._client_encoding),
-                s[1:].decode(self._client_encoding)) for s in
-            data.split(NULL_BYTE) if s != b'')
+            (s[:1].decode(self._client_encoding), s[1:].decode(self._client_encoding))
+            for s in data.split(NULL_BYTE)
+            if s != b""
+        )
 
         self.error = DatabaseError(msg)
 
@@ -339,7 +375,7 @@ class CoreConnection():
         pass
 
     def handle_PARAMETER_DESCRIPTION(self, data, context):
-        '''
+        """
         ParameterDescription (B)
 
             Byte1('t')
@@ -357,7 +393,7 @@ class CoreConnection():
             Int32
 
                 Specifies the object ID of the parameter data type.
-        '''
+        """
 
         # count = h_unpack(data)[0]
         # context.parameter_oids = unpack_from("!" + "i" * count, data, 2)
@@ -374,7 +410,8 @@ class CoreConnection():
         # column_formats = unpack_from('!' + 'h' * num_cols, data, 3)
         if ps.stream is None:
             raise InterfaceError(
-                "An output stream is required for the COPY OUT response.")
+                "An output stream is required for the COPY OUT response."
+            )
 
     def handle_COPY_DATA(self, data, results):
         results.stream.write(data)
@@ -386,7 +423,8 @@ class CoreConnection():
         # column_formats = unpack_from('!' + 'h' * num_cols, data, 3)
         if results.stream is None:
             raise InterfaceError(
-                "An input stream is required for the COPY IN response.")
+                "An input stream is required for the COPY IN response."
+            )
 
         bffr = bytearray(8192)
         while True:
@@ -416,7 +454,7 @@ class CoreConnection():
         idx = 4
         null_idx = data.find(NULL_BYTE, idx)
         channel = data[idx:null_idx].decode("ascii")
-        payload = data[null_idx+1:-1].decode('ascii')
+        payload = data[null_idx + 1 : -1].decode("ascii")
 
         self.notifications.append((backend_pid, channel, payload))
 
@@ -463,8 +501,9 @@ class CoreConnection():
         elif auth_code == 3:
             if self.password is None:
                 raise InterfaceError(
-                    "server requesting password authentication, but no "
-                    "password was provided")
+                    "server requesting password authentication, but no password was "
+                    "provided"
+                )
             self._send_message(PASSWORD, self.password + NULL_BYTE)
             self._flush()
         elif auth_code == 5:
@@ -478,11 +517,12 @@ class CoreConnection():
             salt = b"".join(cccc_unpack(data, 4))
             if self.password is None:
                 raise InterfaceError(
-                    "server requesting MD5 password authentication, but no "
-                    "password was provided")
+                    "server requesting MD5 password authentication, but no password "
+                    "was provided"
+                )
             pwd = b"md5" + md5(
-                md5(self.password + self.user).hexdigest().encode("ascii") +
-                salt).hexdigest().encode("ascii")
+                md5(self.password + self.user).hexdigest().encode("ascii") + salt
+            ).hexdigest().encode("ascii")
             # Byte1('p') - Identifies the message as a password message.
             # Int32 - Message length including self.
             # String - The password.  Password may be encrypted.
@@ -491,43 +531,43 @@ class CoreConnection():
 
         elif auth_code == 10:
             # AuthenticationSASL
-            mechanisms = [
-                m.decode('ascii') for m in data[4:-1].split(NULL_BYTE)]
+            mechanisms = [m.decode("ascii") for m in data[4:-2].split(NULL_BYTE)]
 
-            self.auth = ScramClient(
-                mechanisms, self.user.decode('utf8'),
-                self.password.decode('utf8'))
+            self.auth = scramp.ScramClient(
+                mechanisms,
+                self.user.decode("utf8"),
+                self.password.decode("utf8"),
+                channel_binding=self.channel_binding,
+            )
 
-            init = self.auth.get_client_first().encode('utf8')
+            init = self.auth.get_client_first().encode("utf8")
+            mech = self.auth.mechanism_name.encode("ascii") + NULL_BYTE
 
             # SASLInitialResponse
-            self._write(
-                create_message(
-                    PASSWORD,
-                    b'SCRAM-SHA-256' + NULL_BYTE + i_pack(len(init)) + init))
+            self._write(create_message(PASSWORD, mech + i_pack(len(init)) + init))
             self._flush()
 
         elif auth_code == 11:
             # AuthenticationSASLContinue
-            self.auth.set_server_first(data[4:].decode('utf8'))
+            self.auth.set_server_first(data[4:].decode("utf8"))
 
             # SASLResponse
-            msg = self.auth.get_client_final().encode('utf8')
+            msg = self.auth.get_client_final().encode("utf8")
             self._write(create_message(PASSWORD, msg))
             self._flush()
 
         elif auth_code == 12:
             # AuthenticationSASLFinal
-            self.auth.set_server_final(data[4:].decode('utf8'))
+            self.auth.set_server_final(data[4:].decode("utf8"))
 
         elif auth_code in (2, 4, 6, 7, 8, 9):
             raise InterfaceError(
-                "Authentication method " + str(auth_code) +
-                " not supported by pg8000.")
+                f"Authentication method {auth_code} not supported by pg8000."
+            )
         else:
             raise InterfaceError(
-                "Authentication method " + str(auth_code) +
-                " not recognized by pg8000.")
+                f"Authentication method {auth_code} not recognized by pg8000."
+            )
 
     def handle_READY_FOR_QUERY(self, data, ps):
         # Byte1 -   Status indicator.
@@ -536,157 +576,31 @@ class CoreConnection():
     def handle_BACKEND_KEY_DATA(self, data, ps):
         self._backend_key_data = data
 
-    def array_inspect(self, value):
-        # Check if array has any values. If empty, we can just assume it's an
-        # array of strings
-        first_element = converters.array_find_first_element(value)
-        if first_element is None:
-            oid = 25
-            # Use binary ARRAY format to avoid having to properly
-            # escape text in the array literals
-            array_oid = converters.PG_ARRAY_TYPES[oid]
-        else:
-            # supported array output
-            typ = type(first_element)
-
-            if typ == bool:
-                oid = 16
-                array_oid = converters.PG_ARRAY_TYPES[oid]
-
-            elif issubclass(typ, int):
-                # special int array support -- send as smallest possible array
-                # type
-                typ = int
-                int2_ok, int4_ok, int8_ok = True, True, True
-                for v in converters.array_flatten(value):
-                    if v is None:
-                        continue
-                    if min_int2 < v < max_int2:
-                        continue
-                    int2_ok = False
-                    if min_int4 < v < max_int4:
-                        continue
-                    int4_ok = False
-                    if min_int8 < v < max_int8:
-                        continue
-                    int8_ok = False
-                if int2_ok:
-                    array_oid = 1005  # INT2[]
-                elif int4_ok:
-                    array_oid = 1007  # INT4[]
-                elif int8_ok:
-                    array_oid = 1016  # INT8[]
-                else:
-                    raise InterfaceError(
-                        "numeric not supported as array contents")
-            else:
-                try:
-                    oid, _ = self.make_param(first_element)
-
-                    # If unknown or string, assume it's a string array
-                    if oid in (705, 1043, 25):
-                        oid = 25
-                        # Use binary ARRAY format to avoid having to properly
-                        # escape text in the array literals
-                    array_oid = converters.PG_ARRAY_TYPES[oid]
-                except KeyError:
-                    raise InterfaceError(
-                        "oid " + str(oid) + " not supported as array contents")
-
-        return (array_oid, self.array_out)
-
-    def array_out(self, ar):
-        result = []
-        for v in ar:
-
-            if isinstance(v, list):
-                val = self.array_out(v)
-
-            elif v is None:
-                val = 'NULL'
-
-            elif isinstance(v, str):
-                val = converters.array_string_escape(v)
-
-            else:
-                _, val = self.make_param(v)
-
-            result.append(val)
-
-        return '{' + ','.join(result) + '}'
-
-    def make_param(self, value):
-        typ = type(value)
-        try:
-            oid, func = self.py_types[typ]
-        except KeyError:
-            try:
-                oid, func = self.inspect_funcs[typ](value)
-            except KeyError as e:
-                oid, func = None, None
-                for k, v in self.py_types.items():
-                    try:
-                        if isinstance(value, k):
-                            oid, func = v
-                            break
-                    except TypeError:
-                        pass
-
-                if oid is None:
-                    for k, v in self.inspect_funcs.items():
-                        try:
-                            if isinstance(value, k):
-                                oid, func = v(value)
-                                break
-                        except TypeError:
-                            pass
-                        except KeyError:
-                            pass
-
-                if oid is None:
-                    raise InterfaceError(
-                        "type " + str(e) + " not mapped to pg type")
-
-        return oid, func(value)
-
-    def make_params(self, values):
-        if len(values) == 0:
-            return (), ()
-        else:
-            oids, params = zip(*map(self.make_param, values))
-            return tuple(oids), tuple(params)
-
-    def inspect_datetime(self, value):
-        if value.tzinfo is None:
-            return self.py_types[1114]  # timestamp
-        else:
-            return self.py_types[1184]  # send as timestamptz
-
-    def inspect_int(self, value):
-        if min_int2 < value < max_int2:
-            return self.py_types[21]
-        if min_int4 < value < max_int4:
-            return self.py_types[23]
-        if min_int8 < value < max_int8:
-            return self.py_types[20]
-        return self.py_types[Decimal]
-
     def handle_ROW_DESCRIPTION(self, data, context):
         count = h_unpack(data)[0]
         idx = 2
         columns = []
         input_funcs = []
         for i in range(count):
-            name = data[idx:data.find(NULL_BYTE, idx)]
+            name = data[idx : data.find(NULL_BYTE, idx)]
             idx += len(name) + 1
             field = dict(
-                zip((
-                    "table_oid", "column_attrnum", "type_oid", "type_size",
-                    "type_modifier", "format"), ihihih_unpack(data, idx)))
-            field['name'] = name.decode(self._client_encoding)
+                zip(
+                    (
+                        "table_oid",
+                        "column_attrnum",
+                        "type_oid",
+                        "type_size",
+                        "type_modifier",
+                        "format",
+                    ),
+                    ihihih_unpack(data, idx),
+                )
+            )
+            field["name"] = name.decode(self._client_encoding)
             idx += 18
             columns.append(field)
-            input_funcs.append(self.pg_types[field['type_oid']])
+            input_funcs.append(self.pg_types[field["type_oid"]])
 
         context.columns = columns
         context.input_funcs = input_funcs
@@ -718,8 +632,7 @@ class CoreConnection():
         except AttributeError:
             raise InterfaceError("connection is closed")
 
-    def execute_unnamed(
-            self, statement, vals=(), input_oids=None, stream=None):
+    def execute_unnamed(self, statement, vals=(), input_oids=None, stream=None):
         context = Context(stream=stream)
 
         if len(vals) == 0 and stream is None:
@@ -727,13 +640,11 @@ class CoreConnection():
             self._flush()
             self.handle_messages(context)
         else:
-            param_oids, params = self.make_params(vals)
+            param_oids, params = make_params(self.py_types, vals)
             if input_oids is None:
                 oids = param_oids
             else:
-                oids = [
-                    (p if i is None else i) for p, i in zip(
-                        param_oids, input_oids)]
+                oids = [(p if i is None else i) for p, i in zip(param_oids, input_oids)]
 
             self.send_PARSE(NULL_BYTE, statement, oids)
             self._write(SYNC_MSG)
@@ -764,8 +675,8 @@ class CoreConnection():
     def prepare_statement(self, statement, oids):
 
         for i in count():
-            statement_name = '_'.join(("pg8000", "statement", str(i)))
-            statement_name_bin = statement_name.encode('ascii') + NULL_BYTE
+            statement_name = "_".join(("pg8000", "statement", str(i)))
+            statement_name_bin = statement_name.encode("ascii") + NULL_BYTE
             if statement_name_bin not in self._statement_nums:
                 self._statement_nums.add(statement_name_bin)
                 break
@@ -830,7 +741,8 @@ class CoreConnection():
         # For each result-column format code:
         #   Int16 - The format code.
         retval = bytearray(
-            NULL_BYTE + statement_name_bin + h_pack(0) + h_pack(len(params)))
+            NULL_BYTE + statement_name_bin + h_pack(0) + h_pack(len(params))
+        )
 
         for value in params:
             if value is None:
@@ -857,7 +769,7 @@ class CoreConnection():
         context.columns = []
 
     def handle_COMMAND_COMPLETE(self, data, context):
-        values = data[:-1].split(b' ')
+        values = data[:-1].split(b" ")
         command = values[0]
         if command in self._commands_with_count:
             row_count = int(values[-1])
@@ -875,8 +787,7 @@ class CoreConnection():
             if vlen == -1:
                 v = None
             else:
-                v = func(
-                    str(data[idx:idx + vlen], encoding=self._client_encoding))
+                v = func(str(data[idx : idx + vlen], encoding=self._client_encoding))
                 idx += vlen
             row.append(v)
         results.rows.append(row)
@@ -885,7 +796,12 @@ class CoreConnection():
         code = self.error = None
 
         while code != READY_FOR_QUERY:
-            code, data_len = ci_unpack(self._read(5))
+
+            try:
+                code, data_len = ci_unpack(self._read(5))
+            except struct.error as e:
+                raise InterfaceError("network error on read") from e
+
             self.message_types[code](self._read(data_len - 4), context)
 
         if self.error is not None:
@@ -909,37 +825,39 @@ class CoreConnection():
     #   Byte1 - code identifying the field type (see responseKeys)
     #   String - field value
     def handle_NOTICE_RESPONSE(self, data, ps):
-        self.notices.append(
-            dict((s[0:1], s[1:]) for s in data.split(NULL_BYTE)))
+        self.notices.append(dict((s[0:1], s[1:]) for s in data.split(NULL_BYTE)))
 
     def handle_PARAMETER_STATUS(self, data, ps):
         pos = data.find(NULL_BYTE)
-        key, value = data[:pos], data[pos + 1:-1]
+        key, value = data[:pos], data[pos + 1 : -1]
         self.parameter_statuses.append((key, value))
         if key == b"client_encoding":
             encoding = value.decode("ascii").lower()
-            self._client_encoding = converters.pg_to_py_encodings.get(
-                encoding, encoding)
+            self._client_encoding = PG_PY_ENCODINGS.get(encoding, encoding)
 
         elif key == b"integer_datetimes":
-            if value == b'on':
+            if value == b"on":
                 pass
 
             else:
                 pass
 
         elif key == b"server_version":
-            self._server_version = LooseVersion(value.decode('ascii'))
-            if self._server_version < LooseVersion('8.2.0'):
+            self._server_version = LooseVersion(value.decode("ascii"))
+            if self._server_version < LooseVersion("8.2.0"):
+                self._commands_with_count = (b"INSERT", b"DELETE", b"UPDATE", b"MOVE")
+            elif self._server_version < LooseVersion("9.0.0"):
                 self._commands_with_count = (
-                    b"INSERT", b"DELETE", b"UPDATE", b"MOVE")
-            elif self._server_version < LooseVersion('9.0.0'):
-                self._commands_with_count = (
-                    b"INSERT", b"DELETE", b"UPDATE", b"MOVE", b"FETCH",
-                    b"COPY")
+                    b"INSERT",
+                    b"DELETE",
+                    b"UPDATE",
+                    b"MOVE",
+                    b"FETCH",
+                    b"COPY",
+                )
 
 
-class Context():
+class Context:
     def __init__(self, stream=None, columns=None, input_funcs=None):
         self.rows = []
         self.row_count = -1
