@@ -1,28 +1,23 @@
-import pg8000
-
 import pytest
 
+import pg8000
+
 
 def testUnixSocketMissing():
-    conn_params = {
-        'unix_sock': "/file-does-not-exist",
-        'user': "doesn't-matter"
-    }
+    conn_params = {"unix_sock": "/file-does-not-exist", "user": "doesn't-matter"}
 
     with pytest.raises(pg8000.dbapi.InterfaceError):
         pg8000.dbapi.connect(**conn_params)
 
 
 def test_internet_socket_connection_refused():
-    conn_params = {
-        'port': 0,
-        'user': "doesn't-matter"
-    }
+    conn_params = {"port": 0, "user": "doesn't-matter"}
 
     with pytest.raises(
-            pg8000.dbapi.InterfaceError,
-            match="Can't create a connection to host localhost and port 0 "
-            "\\(timeout is None and source_address is None\\)."):
+        pg8000.dbapi.InterfaceError,
+        match="Can't create a connection to host localhost and port 0 "
+        "\\(timeout is None and source_address is None\\).",
+    ):
         pg8000.dbapi.connect(**conn_params)
 
 
@@ -43,7 +38,7 @@ def test_notify(con):
 
     cursor.execute("VALUES (1, 2), (3, 4), (5, 6)")
     assert len(con.notifications) == 1
-    assert con.notifications[0] == (backend_pid, "test", '')
+    assert con.notifications[0] == (backend_pid, "test", "")
 
 
 def test_notify_with_payload(con):
@@ -57,38 +52,37 @@ def test_notify_with_payload(con):
 
     cursor.execute("VALUES (1, 2), (3, 4), (5, 6)")
     assert len(con.notifications) == 1
-    assert con.notifications[0] == (backend_pid, "test", 'Parnham')
+    assert con.notifications[0] == (backend_pid, "test", "Parnham")
 
 
 def testUnicodeDatabaseName(db_kwargs):
     db_kwargs["database"] = "pg8000_sn\uFF6Fw"
 
     # Should only raise an exception saying db doesn't exist
-    with pytest.raises(pg8000.dbapi.DatabaseError, match='3D000'):
+    with pytest.raises(pg8000.dbapi.DatabaseError, match="3D000"):
         pg8000.dbapi.connect(**db_kwargs)
 
 
 def testBytesDatabaseName(db_kwargs):
     """ Should only raise an exception saying db doesn't exist """
 
-    db_kwargs["database"] = bytes("pg8000_sn\uFF6Fw", 'utf8')
-    with pytest.raises(pg8000.dbapi.DatabaseError, match='3D000'):
+    db_kwargs["database"] = bytes("pg8000_sn\uFF6Fw", "utf8")
+    with pytest.raises(pg8000.dbapi.DatabaseError, match="3D000"):
         pg8000.dbapi.connect(**db_kwargs)
 
 
 def testBytesPassword(con, db_kwargs):
     # Create user
-    username = 'boltzmann'
-    password = 'cha\uFF6Fs'
+    username = "boltzmann"
+    password = "cha\uFF6Fs"
     cur = con.cursor()
-    cur.execute(
-        "create user " + username + " with password '" + password + "';")
+    cur.execute("create user " + username + " with password '" + password + "';")
     con.commit()
 
-    db_kwargs['user'] = username
-    db_kwargs['password'] = password.encode('utf8')
-    db_kwargs['database'] = 'pg8000_md5'
-    with pytest.raises(pg8000.dbapi.DatabaseError, match='3D000'):
+    db_kwargs["user"] = username
+    db_kwargs["password"] = password.encode("utf8")
+    db_kwargs["database"] = "pg8000_md5"
+    with pytest.raises(pg8000.dbapi.DatabaseError, match="3D000"):
         pg8000.dbapi.connect(**db_kwargs)
 
     cur.execute("drop role " + username)
@@ -103,9 +97,7 @@ def test_broken_pipe_read(con, db_kwargs):
     pid1 = cur1.fetchone()[0]
 
     cur2.execute("select pg_terminate_backend(%s)", (pid1,))
-    with pytest.raises(
-            pg8000.dbapi.InterfaceError,
-            match="network error on read"):
+    with pytest.raises(pg8000.dbapi.InterfaceError, match="network error on read"):
         cur1.execute("select 1")
 
 
@@ -134,33 +126,33 @@ def test_broken_pipe_unpack(con):
     cur.execute("select pg_backend_pid()")
     pid1 = cur.fetchone()[0]
 
-    with pytest.raises(
-            pg8000.dbapi.InterfaceError, match="network error"):
+    with pytest.raises(pg8000.dbapi.InterfaceError, match="network error"):
         cur.execute("select pg_terminate_backend(%s)", (pid1,))
 
 
 def testApplicatioName(db_kwargs):
-    app_name = 'my test application name'
-    db_kwargs['application_name'] = app_name
+    app_name = "my test application name"
+    db_kwargs["application_name"] = app_name
     with pg8000.dbapi.connect(**db_kwargs) as db:
         cur = db.cursor()
         cur.execute(
-            'select application_name from pg_stat_activity '
-            ' where pid = pg_backend_pid()')
+            "select application_name from pg_stat_activity "
+            " where pid = pg_backend_pid()"
+        )
 
         application_name = cur.fetchone()[0]
         assert application_name == app_name
 
 
 def test_application_name_integer(db_kwargs):
-    db_kwargs['application_name'] = 1
+    db_kwargs["application_name"] = 1
     with pytest.raises(
-            pg8000.dbapi.InterfaceError,
-            match="The parameter application_name can't be of type "
-            "<class 'int'>."):
+        pg8000.dbapi.InterfaceError,
+        match="The parameter application_name can't be of type " "<class 'int'>.",
+    ):
         pg8000.dbapi.connect(**db_kwargs)
 
 
 def test_application_name_bytearray(db_kwargs):
-    db_kwargs['application_name'] = bytearray(b'Philby')
+    db_kwargs["application_name"] = bytearray(b"Philby")
     pg8000.dbapi.connect(**db_kwargs)
